# Home Assistant Neon Skill

Uses [PHAL Home Assistant plugin](https://github.com/OpenVoiceOS/ovos-PHAL-plugin-homeassistant)

Still a work in progress - please don't expect it to work yet :)

`pip install neon-homeassistant-skill`
